@@ -50,11 +50,18 @@ calc.pl - Calculator example in Parse::Eyapp
 
 =head1 AUTHOR
 
-Casiano Rodriguez Leon E<lt>casiano@ull.esE<gt>
+William N. Braswell, Jr. E<lt>wbraswell_cpan@NOSPAM.nym.hush.comE<gt>
+(Remove "NOSPAM".)
 
-=head1 LICENCE AND COPYRIGHT
+=head1 LICENSE AND COPYRIGHT
  
-Copyright (c) 2007 Casiano Rodriguez-Leon (casiano@ull.es). All rights reserved.
+Copyright © 2006, 2007, 2008, 2009, 2010, 2011, 2012 Casiano Rodriguez-Leon.
+Copyright © 2017 William N. Braswell, Jr.
+All Rights Reserved.
+
+Parse::Yapp is Copyright © 1998, 1999, 2000, 2001, Francois Desarmenien.
+Parse::Yapp is Copyright © 2017 William N. Braswell, Jr.
+All Rights Reserved.
 
 These modules are free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
