@@ -2,8 +2,6 @@ package DebugTail;
 use strict;
 use warnings;
 
-use base q{Parse::Eyapp::TailSupport};
-
 sub lex {
   my $self = shift;
 
@@ -15,8 +13,4 @@ sub lex {
   return ('',undef);
 }
 
-sub TERMINAL::info {
-  $_[0]->{attr};
-}
-
 1;
